@@ -49,7 +49,7 @@ For example: core/autoconf:2.69
 A package group string looks like: NAME
 For example: core, gnome, x11))"))
 (define license-message
-  (string-append "Upmf 0.7.1\n"
+  (string-append "Upmf 0.7.2\n"
 		 (_ "\
 Copyright (C) 2013 Aljosha Papsch
 License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>.
@@ -63,47 +63,74 @@ There is NO WARRANTY, to the extent permitted by law.")))
 ;; Set whether bootstrap mode is enabled
 (define bootstrap-mode #f)
 
-(define install-package
-  (lambda (package-string)
-    (if (eq? package-string '())
-	'()
-    (begin (validate-package-string package-string 'no-version)
-	   (statusmsg (_ "Installing package") package-string)
-	   (let* ((package-with-ver (string-split package-string #\:))
-		  (package-name (list-ref package-with-ver 0))
-		  (package-release (if (eq? (length package-with-ver) 2)
-				       (list-ref package-with-ver 1)
-				       "latest"))
-		  (package-file (find-package-file package-name))
-		  (package-obj (load package-file))
-		  (release-to-install (get-release-for package-obj package-release 'verbose))
-		  (extracted-directory (fetch-and-extract (cdr release-to-install)))
-		  (pkg-base-dir (string-append package-dest-dir "/"
-					       (assq-ref package-obj 'section)
-					       "/" (assq-ref package-obj 'name)))
-		  (pkg-dest-dir (string-append pkg-base-dir
-					       "/" (car release-to-install)
-					       (if (eq? bootstrap-mode #f)
-						   ""
-						   "-bootstrap")))
-		  (installed-list '())
-		  (current-installed #f))
-	     (if (access? pkg-dest-dir R_OK)
-		 (if (exec (string-append "rm -rf " pkg-dest-dir))
-		     (display "")
-		     (errormsg (_ "Could not wipe installation directory")
-			       pkg-dest-dir)))
-	     (check-dependencies (assq-ref package-obj 'dependencies))
-	     (apply-patches extracted-directory (assq-ref package-obj 'patches)
-			    (car release-to-install))
-	     (if (install-with-mode (assq-ref package-obj 'mode)
-				    package-obj extracted-directory
-				    pkg-dest-dir)
-		 (begin (unless (eq? (assq-ref package-obj 'install-info) #f)
-				(install-info pkg-dest-dir))
-			(stow-package pkg-base-dir (car release-to-install))
-			(set! installed-packages
-			      (append installed-packages (list package-string))))))))))
+(define (install-package package-string)
+  (if (eq? package-string '())
+      '()
+      (begin (validate-package-string package-string 'no-version)
+	     (statusmsg (_ "Installing package")
+			package-string)
+	     (let* ((package-with-ver (string-split package-string #\:))
+		    (package-name (list-ref package-with-ver 0))
+		    (package-release (if (eq? (length package-with-ver) 2)
+					 (list-ref package-with-ver 1)
+					 "latest"))
+		    (package-file (find-package-file package-name))
+		    (package-obj (load package-file))
+		    (release-to-install (get-release-for package-obj
+							 package-release
+							 'verbose))
+		    (extracted-directory (fetch-and-extract (cdr release-to-install)))
+		    (pkg-base-dir (string-append package-dest-dir
+						 "/"
+						 (assq-ref package-obj 'section)
+						 "/"
+						 (assq-ref package-obj 'name)))
+		    (pkg-dest-dir (string-append pkg-base-dir
+						 "/"
+						 (car release-to-install)
+						 (if (eq? bootstrap-mode #f)
+						     ""
+						     "-bootstrap")))
+		    (installed-list '())
+		    (current-installed #f))
+	       ;; Remove the destination directory (where the package is installed
+	       ;; into)
+	       (if (access? pkg-dest-dir R_OK)
+		   (if (exec (string-append "rm -rf " pkg-dest-dir))
+		       (display "")
+		       (errormsg (_ "Could not wipe installation directory")
+				 pkg-dest-dir)))
+	       ;; Check dependencies.  This might spawn another package installation.
+	       (check-dependencies (assq-ref package-obj 'dependencies))
+	       ;; Apply patches for this package
+	       (apply-patches extracted-directory (assq-ref package-obj 'patches)
+			      (car release-to-install))
+	       ;; Execute pre-hook
+	       (unless (eq? (assq-ref package-obj 'pre-hook)
+			    #f)
+		       (statusmsg "Executing pre-hook")
+		       (exec-list extracted-directory
+				  (assq-ref package-obj 'pre-hook)))
+	       ;; Execute installation mode
+	       (if (install-with-mode (assq-ref package-obj 'mode)
+				      package-obj
+				      extracted-directory
+				      pkg-dest-dir)
+		   ;; Execute post-hook
+		   (begin (unless (eq? (assq-ref package-obj 'post-hook)
+				       #f)
+				  (exec-list pkg-dest-dir
+					     (assq-ref package-obj 'post-hook)))
+			  ;; Install Info files
+			  (unless (eq? (assq-ref package-obj 'install-info)
+				       #f)
+				  (install-info pkg-dest-dir))
+			  ;; Stow package
+			  (stow-package pkg-base-dir
+					(car release-to-install))
+			  ;; Add package to success list
+			  (set! installed-packages
+				(append installed-packages (list package-string)))))))))
 
 (define remove-package
   (lambda (package-string)
