@@ -62,4 +62,4 @@
 			  (do ((k 0 (1+ k)))
 			      ((> k (- (length install-list) 1)))
 			    (install-package (list-ref install-list k))))
-			(errormsg (_ "Cannot continue: not all dependencies installed") 'fatal)))))))))
+			(errormsg (_ "Cannot continue: not all dependencies installed") #f 'fatal)))))))))
