@@ -41,7 +41,11 @@
 	   (child-stream #f))
       (do ((k (readdir directory-stream)))
 	  ((eof-object? k))
-	(unless (or (string=? k ".") (string=? k "..") (string=? k "groups"))
+	(unless (or (string-prefix? "." k)
+		    (string=? k "groups")
+		    (string=? k "COPYING")
+		    (string=? k "INSTALL")
+		    (string=? k "README"))
 		(begin (set! child-stream (opendir (string-append
 						    packagefile-directory
 						    "/" k)))
@@ -73,6 +77,8 @@
 ;; NEEDLE can be the name with or without the section.
 (define find-package
   (lambda (needle)
+    (if (or (string=? needle ".") (string=? needle ".."))
+	(errormsg (_ "Invalid search string") needle 'fatal))
     (let ((package-file (find-package-file needle)))
       (if (string? package-file)
 	  (print-package-stat (load package-file))))))
