@@ -17,7 +17,6 @@
 
 #include <config.h>
 #include <gettext.h>
-#include "package/package.h"
 #include "version-comp.h"
 
 static void
@@ -40,7 +39,6 @@ main (int argc, char **argv)
 static void
 inner_main (void *closure, int argc, char **argv)
 {    
-  init_package_type ();
   init_version_functions ();
   scm_primitive_load_path (scm_from_locale_string ("upmf/basic.scm"));
 }
